==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/Budgets/DescribeSubscribersForNotification.pm <==

package Paws::Budgets::DescribeSubscribersForNotification;
  use Moose;
  has AccountId => (is => 'ro', isa => 'Str', required => 1);
  has BudgetName => (is => 'ro', isa => 'Str', required => 1);
  has MaxResults => (is => 'ro', isa => 'Int');
  has NextToken => (is => 'ro', isa => 'Str');
  has Notification => (is => 'ro', isa => 'Paws::Budgets::Notification', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeSubscribersForNotification');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Budgets::DescribeSubscribersForNotificationResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Budgets::DescribeSubscribersForNotification - Arguments for method DescribeSubscribersForNotification on L<Paws::Budgets>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeSubscribersForNotification on the
L<AWS Budgets|Paws::Budgets> service. Use the attributes of this class
as arguments to method DescribeSubscribersForNotification.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeSubscribersForNotification.

=head1 SYNOPSIS

    my $budgets = Paws->service('Budgets');
    my $DescribeSubscribersForNotificationResponse =
      $budgets->DescribeSubscribersForNotification(
      AccountId    => 'MyAccountId',
      BudgetName   => 'MyBudgetName',
      Notification => {
        ComparisonOperator =>
          'GREATER_THAN',    # values: GREATER_THAN, LESS_THAN, EQUAL_TO
        NotificationType => 'ACTUAL',    # values: ACTUAL, FORECASTED
        Threshold        => 1,           # min: 0.1, max: 1000000000
        ThresholdType =>
          'PERCENTAGE',    # values: PERCENTAGE, ABSOLUTE_VALUE; OPTIONAL
      },
      MaxResults => 1,                    # OPTIONAL
      NextToken  => 'MyGenericString',    # OPTIONAL
      );

    # Results:
    my $NextToken   = $DescribeSubscribersForNotificationResponse->NextToken;
    my $Subscribers = $DescribeSubscribersForNotificationResponse->Subscribers;

# Returns a L<Paws::Budgets::DescribeSubscribersForNotificationResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/budgets/DescribeSubscribersForNotification>

=head1 ATTRIBUTES


=head2 B<REQUIRED> AccountId => Str

The C<accountId> that is associated with the budget whose subscribers
you want descriptions of.



=head2 B<REQUIRED> BudgetName => Str

The name of the budget whose subscribers you want descriptions of.



=head2 MaxResults => Int

Optional integer. Specifies the maximum number of results to return in
response.



=head2 NextToken => Str

The pagination token that indicates the next set of results to
retrieve.



=head2 B<REQUIRED> Notification => L<Paws::Budgets::Notification>

The notification whose subscribers you want to list.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeSubscribersForNotification in L<Paws::Budgets>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.42.tar.gz: Paws-0.42/lib/Paws/Budgets/DescribeSubscribersForNotification.pm <==

package Paws::Budgets::DescribeSubscribersForNotification;
  use Moose;
  has AccountId => (is => 'ro', isa => 'Str', required => 1);
  has BudgetName => (is => 'ro', isa => 'Str', required => 1);
  has MaxResults => (is => 'ro', isa => 'Int');
  has NextToken => (is => 'ro', isa => 'Str');
  has Notification => (is => 'ro', isa => 'Paws::Budgets::Notification', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeSubscribersForNotification');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Budgets::DescribeSubscribersForNotificationResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Budgets::DescribeSubscribersForNotification - Arguments for method DescribeSubscribersForNotification on L<Paws::Budgets>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeSubscribersForNotification on the
L<AWS Budgets|Paws::Budgets> service. Use the attributes of this class
as arguments to method DescribeSubscribersForNotification.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeSubscribersForNotification.

=head1 SYNOPSIS

    my $budgets = Paws->service('Budgets');
    my $DescribeSubscribersForNotificationResponse =
      $budgets->DescribeSubscribersForNotification(
      AccountId    => 'MyAccountId',
      BudgetName   => 'MyBudgetName',
      Notification => {
        ComparisonOperator =>
          'GREATER_THAN',    # values: GREATER_THAN, LESS_THAN, EQUAL_TO
        NotificationType  => 'ACTUAL',    # values: ACTUAL, FORECASTED
        Threshold         => 1,           # max: 1000000000
        NotificationState => 'OK',        # values: OK, ALARM; OPTIONAL
        ThresholdType =>
          'PERCENTAGE',    # values: PERCENTAGE, ABSOLUTE_VALUE; OPTIONAL
      },
      MaxResults => 1,                    # OPTIONAL
      NextToken  => 'MyGenericString',    # OPTIONAL
      );

    # Results:
    my $NextToken   = $DescribeSubscribersForNotificationResponse->NextToken;
    my $Subscribers = $DescribeSubscribersForNotificationResponse->Subscribers;

# Returns a L<Paws::Budgets::DescribeSubscribersForNotificationResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/budgets/DescribeSubscribersForNotification>

=head1 ATTRIBUTES


=head2 B<REQUIRED> AccountId => Str

The C<accountId> that is associated with the budget whose subscribers
you want descriptions of.



=head2 B<REQUIRED> BudgetName => Str

The name of the budget whose subscribers you want descriptions of.



=head2 MaxResults => Int

An optional integer that represents how many entries a paginated
response contains. The maximum is 100.



=head2 NextToken => Str

The pagination token that you include in your request to indicate the
next set of results that you want to retrieve.



=head2 B<REQUIRED> Notification => L<Paws::Budgets::Notification>

The notification whose subscribers you want to list.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeSubscribersForNotification in L<Paws::Budgets>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
